@@ -51,7 +51,6 @@
 #include <sql-parser/gda-statement-struct-util.h>
 #include <libgda/gda-set.h>
 #include <libgda/gda-blob-op.h>
-#include <libgda/gda-statement-priv.h>
 
 #include <libgda/binreloc/gda-binreloc.h>
 
@@ -172,10 +171,6 @@ gda_g_type_from_string (const gchar *str)
 			type = G_TYPE_CHAR;
 		else if (!g_ascii_strcasecmp (str, "uchar"))
 			type = G_TYPE_UCHAR;
-		else if (!g_ascii_strcasecmp (str, "gshort"))
-			type = GDA_TYPE_SHORT;
-		else if (!g_ascii_strcasecmp (str, "gushort"))
-			type = GDA_TYPE_USHORT;
 		else
 			/* could not find a valid GType for @str */
 			type = G_TYPE_INVALID;
@@ -722,9 +717,7 @@ gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *
 	if (vnode) {
 		xmlChar *this_lang, *isnull;
 		const gchar *lang = gda_lang_locale;
-		GType gdatype;
 
-		gdatype = gda_holder_get_g_type (holder);
 		while (vnode) {
 			if (xmlNodeIsText (vnode)) {
 				vnode = vnode->next;
@@ -1274,7 +1267,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		if (insert_stmt) {
 			GdaSqlParamSpec *pspec = g_new0 (GdaSqlParamSpec, 1);
 			pspec->name = g_strdup_printf ("+%d", colindex);
-			pspec->g_type = tcol->gtype != G_TYPE_INVALID ? tcol->gtype: G_TYPE_STRING;
+			pspec->g_type = (tcol->gtype != GDA_TYPE_NULL) ? tcol->gtype: G_TYPE_STRING;
 			pspec->nullok = tcol->nullok;
 			expr = gda_sql_expr_new (GDA_SQL_ANY_PART (ist));
 			if (tcol->default_value)
@@ -1289,7 +1282,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		if (update_stmt) {
 			GdaSqlParamSpec *pspec = g_new0 (GdaSqlParamSpec, 1);
 			pspec->name = g_strdup_printf ("+%d", colindex);
-			pspec->g_type = tcol->gtype != G_TYPE_INVALID ? tcol->gtype: G_TYPE_STRING;
+			pspec->g_type = (tcol->gtype != GDA_TYPE_NULL) ? tcol->gtype: G_TYPE_STRING;
 			pspec->nullok = tcol->nullok;
 			expr = gda_sql_expr_new (GDA_SQL_ANY_PART (ust));
 			if (tcol->default_value)
@@ -1899,62 +1892,6 @@ stmt_rewrite_update_default_keyword (GdaSqlStatementUpdate *upd, GdaSet *params,
 	return TRUE;
 }
 
-
-static gboolean
-foreach_modify_param_type (GdaSqlAnyPart *part, GdaDataModel *model, G_GNUC_UNUSED GError **error)
-{
-	if (part->type != GDA_SQL_ANY_EXPR)
-		return TRUE;
-
-	GdaSqlParamSpec *pspec;
-	pspec = ((GdaSqlExpr*) part)->param_spec;
-	if (!pspec || !pspec->name)
-		return TRUE;
-
-	if ((pspec->name [0] == '+') || (pspec->name [0] == '-')) {
-		long int li;
-		char *end;
-		li = strtol ((pspec->name) + 1, &end, 10);
-		if ((! *end) && (li <= G_MAXINT) && (li >= G_MININT) && (li < gda_data_model_get_n_columns (model)))  {
-			GdaColumn *col;
-			col = gda_data_model_describe_column (model, (gint) li);
-			if (col && (gda_column_get_g_type (col) != GDA_TYPE_NULL))
-				pspec->g_type = gda_column_get_g_type (col);
-		}
-	}
-	return TRUE;
-}
-
-/**
- * gda_modify_statement_param_types:
- * @stmt: a #GdaStatement
- * @model: a #GdaDataModel
- *
- * Modifies the parameters in @stmt which will be mapped to columns in @model (using the +&lt;colindex&gt; or
- * -&lt;colindex&gt; syntax) to map the column types of @model.
- *
- * Since: 5.2
- */
-void
-_gda_modify_statement_param_types (GdaStatement *stmt, GdaDataModel *model)
-{
-	g_return_if_fail (GDA_IS_STATEMENT (stmt));
-	g_return_if_fail (GDA_IS_DATA_MODEL (model));
-	GdaSqlStatement *sqlst;
-
-	sqlst = _gda_statement_get_internal_struct (stmt);
-	if (!sqlst || !sqlst->contents)
-		return;
-
-	if ((sqlst->stmt_type == GDA_SQL_STATEMENT_INSERT) ||
-	    (sqlst->stmt_type == GDA_SQL_STATEMENT_UPDATE) ||
-	    (sqlst->stmt_type == GDA_SQL_STATEMENT_DELETE)) {
-		GdaSqlAnyPart *top;
-		top = (GdaSqlAnyPart*) sqlst->contents;
-		gda_sql_any_part_foreach (top, (GdaSqlForeachFunc) foreach_modify_param_type, model, NULL);
-	}
-}
-
 /**
  * gda_identifier_hash:
  * @id: an identifier string
@@ -2602,7 +2539,7 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 		gchar *tmp, *ptr;
 		tmp = _remove_quotes (g_strdup (id));
 		if (is_keyword (tmp)) {
-			ptr = gda_sql_identifier_add_quotes (tmp);
+			ptr = gda_sql_identifier_force_quotes (tmp);
 			g_free (tmp);
 			return ptr;
 		}
@@ -2614,7 +2551,7 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 				    (*ptr == '_'))
 					continue;
 				else {
-					ptr = gda_sql_identifier_add_quotes (tmp);
+					ptr = gda_sql_identifier_force_quotes (tmp);
 					g_free (tmp);
 					return ptr;
 				}
@@ -2629,7 +2566,7 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 					    (*ptr == '_'))
 						continue;
 					else {
-						ptr = gda_sql_identifier_add_quotes (tmp);
+						ptr = gda_sql_identifier_force_quotes (tmp);
 						g_free (tmp);
 						return ptr;
 					}
@@ -2637,7 +2574,7 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 				else if ((*ptr >= 'A') && (*ptr <= 'Z'))
 					*ptr += 'a' - 'A';
 				else if ((*ptr >= '0') && (*ptr <= '9') && (ptr == tmp)) {
-					ptr = gda_sql_identifier_add_quotes (tmp);
+					ptr = gda_sql_identifier_force_quotes (tmp);
 					g_free (tmp);
 					return ptr;
 				}
@@ -2652,7 +2589,7 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 			return g_strdup (id);
 		}
 		if (is_keyword (id) || _sql_identifier_needs_quotes (id) || force_quotes)
-			return gda_sql_identifier_add_quotes (id);
+			return gda_sql_identifier_force_quotes (id);
 		
 		/* nothing to do */
 		return g_strdup (id);
@@ -2808,7 +2745,6 @@ gboolean
 gda_rfc1738_decode (gchar *string)
 {
 	gchar *wptr, *rptr;
-	gboolean retval = TRUE;
 
 	if (!string || !*string)
 		return TRUE;
@@ -2845,7 +2781,7 @@ gda_rfc1738_decode (gchar *string)
 			}
 			else {
 				/* error */
-				retval = FALSE;
+				/* TODO: Actually return this? retval = FALSE; murrayc */
 				rptr--;
 			}
 		}
