@@ -105,7 +105,7 @@ static GObjectClass *parent_class = NULL;
  */
 static void
 gda_mysql_recordset_init (GdaMysqlRecordset       *recset,
-			  GdaMysqlRecordsetClass  *klass)
+			  G_GNUC_UNUSED GdaMysqlRecordsetClass  *klass)
 {
 	g_return_if_fail (GDA_IS_MYSQL_RECORDSET (recset));
 	recset->priv = g_new0 (GdaMysqlRecordsetPrivate, 1);
@@ -298,7 +298,8 @@ gda_mysql_recordset_get_type (void)
 			NULL,
 			sizeof (GdaMysqlRecordset),
 			0,
-			(GInstanceInitFunc) gda_mysql_recordset_init
+			(GInstanceInitFunc) gda_mysql_recordset_init,
+			NULL
 		};
 		g_static_mutex_lock (&registering);
 		if (type == 0)
@@ -310,7 +311,7 @@ gda_mysql_recordset_get_type (void)
 }
 
 static GType
-_gda_mysql_type_to_gda (MysqlConnectionData *cdata,
+_gda_mysql_type_to_gda (G_GNUC_UNUSED MysqlConnectionData *cdata,
 			enum enum_field_types  mysql_type, unsigned int charsetnr)
 {
 	GType gtype;
@@ -715,7 +716,7 @@ gda_mysql_recordset_fetch_nb_rows (GdaDataSelect *model)
 }
 
 static GdaRow *
-new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
+new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, GError **error)
 {
 	//g_print ("%s(): NCOLS=%d  ROWNUM=%d\n", __func__, ((GdaDataSelect *) imodel)->prep_stmt->ncols, rownum);
 	int res;
@@ -776,7 +777,7 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 		long long longlongvalue = 0;
 		double doublevalue = 0.0;
 		float floatvalue = 0.;
-		MYSQL_TIME timevalue = { 0 };
+		MYSQL_TIME timevalue = { 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 		my_bool is_null = FALSE;
 		unsigned long length;
 		
@@ -929,14 +930,10 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 				gda_value_set_binary (value, &binary);
 			}
 			else if (type == GDA_TYPE_BLOB) {
-				/* web don't use GdaMysqlBlobOp because it looks like the MySQL
+				/* we don't use GdaMysqlBlobOp because it looks like the MySQL
 				 * API does not support BLOBs accessed in a random way,
 				 * so we return the whole BLOB at once */
-				GdaBlob blob = {
-					.data.data = (guchar*) strvalue,
-					.data.binary_length = length,
-					.op = NULL
-				};
+				GdaBlob blob = { {(guchar*) strvalue, length}, NULL };
 				gda_value_set_blob (value, &blob);
 			}
 			else if (type == G_TYPE_DOUBLE) {
@@ -1007,17 +1004,7 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 /*
  * Create a new filled #GdaRow object for the row at position @rownum, and put it into *row.
  *
- * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
- *  -  If *row is NULL then a new #GdaRow object has to be created, 
- *  -  and otherwise *row contains a #GdaRow object which has already been created 
- *     (through a call to this very function), and in this case it should not be modified
- *     but the function may return FALSE if an error occurred.
- *
- * Memory management for that new GdaRow object is left to the implementation, which
- * can use gda_data_select_take_row(). If new row objects are "given" to the GdaDataSelect implemantation
- * using that method, then this method should detect when all the data model rows have been analyzed
- * (when model->nb_stored_rows == model->advertized_nrows) and then possibly discard the API handle
- * as it won't be used anymore to fetch rows.
+ * Each new GdaRow is given to @model using gda_data_select_take_row().
  */
 static gboolean 
 gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
@@ -1029,12 +1016,9 @@ gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
 
 	imodel = GDA_MYSQL_RECORDSET (model);
 
-	if (*row)
-		return TRUE;
-	
 	*row = new_row_from_mysql_stmt (imodel, rownum, error);
 	if (!*row)
-		return FALSE;
+		return TRUE;
 
 	gda_data_select_take_row (model, *row, rownum);
 	
@@ -1050,14 +1034,9 @@ gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
 /*
  * Create a new filled #GdaRow object for the next cursor row, and put it into *row.
  *
- * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
- *  -  If *row is NULL then a new #GdaRow object has to be created, 
- *  -  and otherwise *row contains a #GdaRow object which has already been created 
- *     (through a call to this very function), and in this case it should not be modified
- *     but the function may return FALSE if an error occurred.
- *
- * Memory management for that new GdaRow object is left to the implementation, which
- * can use gda_data_select_take_row().
+ * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
+ * never keeps a reference to it).
+ * Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean 
 gda_mysql_recordset_fetch_next (GdaDataSelect  *model,
@@ -1067,33 +1046,20 @@ gda_mysql_recordset_fetch_next (GdaDataSelect  *model,
 {
 	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
 
-	// TO_IMPLEMENT;
-
-	// gda_data_select_iter_next () increments rownum
-
-	if (imodel->priv->tmp_row != NULL) {
+	if (imodel->priv->tmp_row)
 		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
-		imodel->priv->tmp_row = NULL;
-	}
-	
 	*row = new_row_from_mysql_stmt (imodel, rownum, error);
-
 	imodel->priv->tmp_row = *row;
 
-	return *row ? TRUE : FALSE;
+	return TRUE;
 }
 
 /*
- * Create a new filled #GdaRow object for the previous cursor row, and put it into *row.
+ * Create a new filled #GdaRow object for the previous cursor row, and put it into *prow.
  *
- * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
- *  -  If *row is NULL then a new #GdaRow object has to be created, 
- *  -  and otherwise *row contains a #GdaRow object which has already been created 
- *     (through a call to this very function), and in this case it should not be modified
- *     but the function may return FALSE if an error occurred.
- *
- * Memory management for that new GdaRow object is left to the implementation, which
- * can use gda_data_select_take_row().
+ * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
+ * never keeps a reference to it).
+ * Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean 
 gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
@@ -1101,9 +1067,12 @@ gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
 				gint            rownum,
 				GError        **error)
 {
-	/*GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;*/
+	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
 
-	TO_IMPLEMENT;
+	if (imodel->priv->tmp_row)
+		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
+	*row = new_row_from_mysql_stmt (imodel, rownum, error);
+	imodel->priv->tmp_row = *row;
 
 	return TRUE;
 }
@@ -1111,14 +1080,9 @@ gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
 /*
  * Create a new filled #GdaRow object for the cursor row at position @rownum, and put it into *row.
  *
- * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
- *  -  If *row is NULL then a new #GdaRow object has to be created, 
- *  -  and otherwise *row contains a #GdaRow object which has already been created 
- *     (through a call to this very function), and in this case it should not be modified
- *     but the function may return FALSE if an error occurred.
- *
- * Memory management for that new GdaRow object is left to the implementation, which
- * can use gda_data_select_take_row().
+ * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
+ * never keeps a reference to it).
+ * Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean 
 gda_mysql_recordset_fetch_at (GdaDataSelect  *model,
@@ -1126,9 +1090,12 @@ gda_mysql_recordset_fetch_at (GdaDataSelect  *model,
 			      gint            rownum,
 			      GError        **error)
 {
-	/*GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;*/
-	
-	TO_IMPLEMENT;
+	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
+
+	if (imodel->priv->tmp_row)
+		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
+	*row = new_row_from_mysql_stmt (imodel, rownum, error);
+	imodel->priv->tmp_row = *row;
 
 	return TRUE;
 }
