@@ -132,7 +132,7 @@ static gchar *internal_sql[] = {
 	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, view_definition, check_option, is_updatable FROM INFORMATION_SCHEMA.views WHERE table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string UNION SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, NULL, NULL, FALSE FROM INFORMATION_SCHEMA.tables WHERE table_schema='information_schema' AND table_type LIKE '%VIEW%' AND table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string",
 
         /* I_STMT_COLUMNS_OF_TABLE */
-	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, column_name, ordinal_position, column_default, CASE is_nullable WHEN 'YES' THEN TRUE ELSE FALSE END AS is_nullable, data_type, NULL, 'gchararray', character_maximum_length,character_octet_length, numeric_precision, numeric_scale, 0, character_set_name, character_set_name, character_set_name, collation_name, collation_name, collation_name, CASE WHEN extra = 'auto_increment' then '" GDA_EXTRA_AUTO_INCREMENT "' ELSE extra END, 1, column_comment FROM INFORMATION_SCHEMA.columns WHERE table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string",
+	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, column_name, ordinal_position, column_default, is_nullable, data_type, NULL, 'gchararray', character_maximum_length,character_octet_length, numeric_precision, numeric_scale, 0, character_set_name, character_set_name, character_set_name, collation_name, collation_name, collation_name, CASE WHEN extra = 'auto_increment' then '" GDA_EXTRA_AUTO_INCREMENT "' ELSE extra END, 1, column_comment FROM INFORMATION_SCHEMA.columns WHERE table_schema = BINARY ##schema::string AND table_name = BINARY ##name::string",
 
         /* I_STMT_COLUMNS_ALL */
 	"SELECT " CATALOG_NAME " AS table_catalog, table_schema, table_name, column_name, ordinal_position, column_default, CASE is_nullable WHEN 'YES' THEN TRUE ELSE FALSE END AS is_nullable, data_type, NULL, 'gchararray', character_maximum_length, character_octet_length, numeric_precision, numeric_scale, 0, character_set_name, character_set_name, character_set_name, collation_name, collation_name, collation_name, CASE WHEN extra = 'auto_increment' then '" GDA_EXTRA_AUTO_INCREMENT "' ELSE extra END, IF(FIND_IN_SET('insert', privileges) != 0 OR FIND_IN_SET('update', privileges) != 0, TRUE, FALSE) AS is_updatable, column_comment FROM INFORMATION_SCHEMA.columns",
@@ -280,7 +280,7 @@ _gda_mysql_provider_meta_init (GdaServerProvider  *provider)
 #endif
 }
 
-#define GDA_MYSQL_GET_REUSEABLE_DATA(cdata) ((cdata) ? * ((GdaMysqlReuseable**) (cdata)) : NULL)
+#define GDA_MYSQL_GET_REUSEABLE_DATA(cdata) (* ((GdaMysqlReuseable**) (cdata)))
 
 gboolean
 _gda_mysql_meta__info (G_GNUC_UNUSED GdaServerProvider  *prov,
@@ -942,87 +942,115 @@ _gda_mysql_meta_tables_views (G_GNUC_UNUSED GdaServerProvider  *prov,
  * Returns a newly created GValue string.
  */
 static inline GValue *
-map_mysql_type_to_gda (const GValue *value, const gchar *vlength)
+map_mysql_type_to_gda (const GValue  *value)
 {
 	const gchar *string = g_value_get_string (value);
 	GValue *newvalue;
 	const gchar *newstring;
 
-	if (!strcmp (string, "bool"))
+	if (strcmp (string, "bool") == 0)
 		newstring = "gboolean";
-	else if (!strcmp (string, "blob"))
+	else
+	if (strcmp (string, "blob") == 0)
 		newstring = "GdaBinary";
-	else if (!strcmp (string, "bigint"))
+	else
+	if (strcmp (string, "bigint") == 0)
 		newstring = "gint64";
-	else if (!strcmp (string, "bigint unsigned"))
+	else
+	if (strcmp (string, "bigint unsigned") == 0)
 		newstring = "guint64";
-	else if (!strcmp (string, "char")) {
-		if (vlength && (G_VALUE_TYPE ((GValue*)vlength) == G_TYPE_INT) &&
-		    (g_value_get_int ((GValue*)vlength) > 1))
-			newstring = "gchararray";
-		else
-			newstring = "gchar";
-	}
-	else if (!strcmp (string, "date"))
-		newstring = "GDate";
-	else if (!strcmp (string, "datetime"))
-		newstring = "GdaTimestamp";
-	else if (!strcmp (string, "decimal"))
-		newstring = "GdaNumeric";
-	else if (!strcmp (string, "double"))
-		newstring = "gdouble";
-	else if (!strcmp (string, "double unsigned"))
-		newstring = "double";
-	else if (!strcmp (string, "enum"))
-		newstring = "gchararray";
-	else if (!strcmp (string, "float"))
-		newstring = "gfloat";
-	else if (!strcmp (string, "float unsigned"))
-		newstring = "gfloat";
-	else if (!strcmp (string, "int"))
-		newstring = "int";
-	else if (!strcmp (string, "unsigned int"))
-		newstring = "guint";
-	else if (!strcmp (string, "long"))
-		newstring = "glong";
-	else if (!strcmp (string, "unsigned long"))
-		newstring = "gulong";
-	else if (!strcmp (string, "longblob"))
-		newstring = "GdaBinary";
-	else if (!strcmp (string, "longtext"))
-		newstring = "GdaBinary";
-	else if (!strcmp (string, "mediumint"))
-		newstring = "gint";
-	else if (!strcmp (string, "mediumint unsigned"))
-		newstring = "guint";
-	else if (!strcmp (string, "mediumblob"))
-		newstring = "GdaBinary";
-	else if (!strcmp (string, "mediumtext"))
-		newstring = "GdaBinary";
-	else if (!strcmp (string, "set"))
-		newstring = "gchararray";
-	else if (!strcmp (string, "smallint"))
-		newstring = "gshort";
-	else if (!strcmp (string, "smallint unsigned"))
-		newstring = "gushort";
-	else if (!strcmp (string, "text"))
-		newstring = "GdaBinary";
-	else if (!strcmp (string, "tinyint"))
+	else
+	if (strcmp (string, "char") == 0)
 		newstring = "gchar";
-	else if (!strcmp (string, "tinyint unsigned"))
-		newstring = "guchar";
-	else if (!strcmp (string, "tinyblob"))
-		newstring = "GdaBinary";
-	else if (!strcmp (string, "time"))
-		newstring = "GdaTime";
-	else if (!strcmp (string, "timestamp"))
+	else
+	if (strcmp (string, "date") == 0)
+		newstring = "GDate";
+	else
+	if (strcmp (string, "datetime") == 0)
 		newstring = "GdaTimestamp";
-	else if (!strcmp (string, "varchar"))
+	else
+	if (strcmp (string, "decimal") == 0)
+		newstring = "GdaNumeric";
+	else
+	if (strcmp (string, "double") == 0)
+		newstring = "gdouble";
+	else
+	if (strcmp (string, "double unsigned") == 0)
+		newstring = "double";
+	else
+	if (strcmp (string, "enum") == 0)
 		newstring = "gchararray";
-	else if (!strcmp (string, "year"))
+	else
+	if (strcmp (string, "float") == 0)
+		newstring = "gfloat";
+	else
+	if (strcmp (string, "float unsigned") == 0)
+		newstring = "gfloat";
+	else
+	if (strcmp (string, "int") == 0)
+		newstring = "int";
+	else
+	if (strcmp (string, "unsigned int") == 0)
+		newstring = "guint";
+	else
+	if (strcmp (string, "long") == 0)
+		newstring = "glong";
+	else
+	if (strcmp (string, "unsigned long") == 0)
+		newstring = "gulong";
+	else
+	if (strcmp (string, "longblob") == 0)
+		newstring = "GdaBinary";
+	else
+	if (strcmp (string, "longtext") == 0)
+		newstring = "GdaBinary";
+	else
+	if (strcmp (string, "mediumint") == 0)
 		newstring = "gint";
 	else
+	if (strcmp (string, "mediumint unsigned") == 0)
+		newstring = "guint";
+	else
+	if (strcmp (string, "mediumblob") == 0)
+		newstring = "GdaBinary";
+	else
+	if (strcmp (string, "mediumtext") == 0)
+		newstring = "GdaBinary";
+	else
+	if (strcmp (string, "set") == 0)
 		newstring = "gchararray";
+	else
+	if (strcmp (string, "smallint") == 0)
+		newstring = "gshort";
+	else
+	if (strcmp (string, "smallint unsigned") == 0)
+		newstring = "gushort";
+	else
+	if (strcmp (string, "text") == 0)
+		newstring = "GdaBinary";
+	else
+	if (strcmp (string, "tinyint") == 0)
+		newstring = "gchar";
+	else
+	if (strcmp (string, "tinyint unsigned") == 0)
+		newstring = "guchar";
+	else
+	if (strcmp (string, "tinyblob") == 0)
+		newstring = "GdaBinary";
+	else
+	if (strcmp (string, "time") == 0)
+		newstring = "GdaTime";
+	else
+	if (strcmp (string, "timestamp") == 0)
+		newstring = "GdaTimestamp";
+	else
+	if (strcmp (string, "varchar") == 0)
+		newstring = "gchararray";
+	else
+	if (strcmp (string, "year") == 0)
+		newstring = "gint";
+	else
+		newstring = "";
 
 	g_value_set_string (newvalue = gda_value_new (G_TYPE_STRING),
 			    newstring);
@@ -1065,16 +1093,13 @@ _gda_mysql_meta__columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 		gint n_rows = gda_data_model_get_n_rows (model);
 		gint i;
 		for (i = 0; i < n_rows; ++i) {
-			const GValue *value1, *value2 = NULL;
-			value1 = gda_data_model_get_value_at (model, 7, i, error);
-			if (value1)
-				value2 = gda_data_model_get_value_at (model, 10, i, error);
-			if (!value1 || !value2) {
+			const GValue *value = gda_data_model_get_value_at (model, 7, i, error);
+			if (!value) {
 				retval = FALSE;
 				break;
 			}
 
-			GValue *newvalue = map_mysql_type_to_gda (value1, (const char*)(value2));
+			GValue *newvalue = map_mysql_type_to_gda (value);
 
 			retval = gda_data_model_set_value_at (GDA_DATA_MODEL(proxy), 9, i, newvalue, error);
 			gda_value_free (newvalue);
@@ -1140,16 +1165,13 @@ _gda_mysql_meta_columns (G_GNUC_UNUSED GdaServerProvider  *prov,
 		gint n_rows = gda_data_model_get_n_rows (model);
 		gint i;
 		for (i = 0; i < n_rows; ++i) {
-			const GValue *value1, *value2 = NULL;
-			value1 = gda_data_model_get_value_at (model, 7, i, error);
-			if (value1)
-				value2 = gda_data_model_get_value_at (model, 10, i, error);
-			if (!value1 || !value2) {
+			const GValue *value = gda_data_model_get_value_at (model, 7, i, error);
+			if (!value) {
 				retval = FALSE;
 				break;
 			}
 
-			GValue *newvalue = map_mysql_type_to_gda (value1, (const char*)value2);
+			GValue *newvalue = map_mysql_type_to_gda (value);
 
 			retval = gda_data_model_set_value_at (GDA_DATA_MODEL(proxy), 9, i, newvalue, error);
 			gda_value_free (newvalue);
